pub struct SyncApplyGuard { /* private fields */ }Available on crate feature
sync only.Expand description
RAII guard that marks the current thread as applying sync changes.
While this guard is held, is_sync_applying() returns true.
The flag is automatically cleared when the guard is dropped,
even on panic (via Drop).
Implementations