SyncPayload

Enum SyncPayload 

pub enum SyncPayload {
    ExperienceCreated(Experience),
    ExperienceUpdated {
        id: ExperienceId,
        update: SerializableExperienceUpdate,
        timestamp: Timestamp,
    },
    ExperienceArchived {
        id: ExperienceId,
        timestamp: Timestamp,
    },
    ExperienceDeleted {
        id: ExperienceId,
        timestamp: Timestamp,
    },
    RelationCreated(ExperienceRelation),
    RelationDeleted {
        id: RelationId,
        timestamp: Timestamp,
    },
    InsightCreated(DerivedInsight),
    InsightDeleted {
        id: InsightId,
        timestamp: Timestamp,
    },
    CollectiveCreated(Collective),
}
Available on crate feature sync only.
The payload of a sync change, containing all data needed to apply the change on the receiving end.

Uses full payloads (not deltas) so the receiver has everything needed including embeddings for HNSW insertion.

Variants



ExperienceCreated(Experience)

A new experience was created.



ExperienceUpdated

An existing experience was updated.

Fields

id: ExperienceId

The experience that was updated.

update: SerializableExperienceUpdate

The fields that changed.

timestamp: Timestamp

When the update occurred.



ExperienceArchived

An experience was soft-deleted (archived).

Fields

id: ExperienceId

The archived experience.

timestamp: Timestamp

When the archive occurred.



ExperienceDeleted

An experience was permanently deleted.

Fields

id: ExperienceId

The deleted experience.

timestamp: Timestamp

When the deletion occurred.



RelationCreated(ExperienceRelation)

A new relation was created.



RelationDeleted

A relation was deleted.

Fields

id: RelationId

The deleted relation.

timestamp: Timestamp

When the deletion occurred.



InsightCreated(DerivedInsight)

A new insight was created.



InsightDeleted

An insight was deleted.

Fields

id: InsightId

The deleted insight.

timestamp: Timestamp

When the deletion occurred.



CollectiveCreated(Collective)

A new collective was created.