pub enum SyncPayload {
ExperienceCreated(Experience),
ExperienceUpdated {
id: ExperienceId,
update: SerializableExperienceUpdate,
timestamp: Timestamp,
},
ExperienceArchived {
id: ExperienceId,
timestamp: Timestamp,
},
ExperienceDeleted {
id: ExperienceId,
timestamp: Timestamp,
},
RelationCreated(ExperienceRelation),
RelationDeleted {
id: RelationId,
timestamp: Timestamp,
},
InsightCreated(DerivedInsight),
InsightDeleted {
id: InsightId,
timestamp: Timestamp,
},
CollectiveCreated(Collective),
}Available on crate feature
sync only.Expand description
The payload of a sync change, containing all data needed to apply the change on the receiving end.
Uses full payloads (not deltas) so the receiver has everything needed including embeddings for HNSW insertion.
Variants
ExperienceCreated(Experience)
A new experience was created.
ExperienceUpdated
An existing experience was updated.
Fields

id: ExperienceIdThe experience that was updated.

update: SerializableExperienceUpdateThe fields that changed.
ExperienceArchived
An experience was soft-deleted (archived).
ExperienceDeleted
An experience was permanently deleted.
RelationCreated(ExperienceRelation)
A new relation was created.
RelationDeleted
A relation was deleted.
InsightCreated(DerivedInsight)
A new insight was created.
InsightDeleted
An insight was deleted.
CollectiveCreated(Collective)
A new collective was created.